#!/etc/opt/openit/perl -w

use strict;

my $cfg = "/etc/opt/openit/openit.env";
my $old = "$cfg.old";
my $new = "$cfg.new";

my @lines;

# Only root can patch
if ( $< ne 0 ) {
    die "Error: Patching must be done as 'root'!\n";
}

# Check for linux
if (`uname -s` !~ /linux/i || `uname -m` !~ /(i.86|x86_64)/) {
    die "Patch only valid for x86 linux architecture\n";
}

# Check for kernel version
my $r = `uname -r`;
my @r = split( '-', $r );
my $re = $r[ 0 ];
my @rel = split( '\.', $re );
if (($rel[ 0 ] < 2) ||
    ($rel[ 0 ] == 2 && $rel[ 1 ] < 4) ||
    ($rel[ 0 ] == 2 && $rel[ 1 ] == 4 && $rel[ 2 ] < 20)) {
    die "Patch only valid for kernel version 2.4.20 or newer\n";
}

open(IN, "$cfg") || die "Error: Unable to read old cfg '$cfg'!\n";
# Slurp in all lines
@lines = <IN>;
close(IN);

if ( grep(/LD_ASSUME_KERNEL/, @lines) ) {
    print("Open iT ENV alrady fixed, skipping!\n");
    exit 0;
}

open(OUT, ">$new") || die "Error: Can't write new cfg '$new'!\n";
foreach my $line (@lines) {
    print OUT $line;
    if($line =~ /^LD_LIBRARY_PATH/) {
	print OUT "LD_ASSUME_KERNEL=2.4.19\n";
	print OUT "export LD_ASSUME_KERNEL\n";
    }
}
close(OUT);

if( ! rename($cfg, $old)) {
    die "Error: Unable to previous config to '$old'!\n";
}

if( ! rename($new, $cfg)) {
    die "Error: Unable to rename new config to '$cfg'!\n";
}

exit 0;
